Documentation
¶
Overview ¶
Package mapcache is very similar to rediscache, except there are no external dependencies and the page output is saved in a map
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cache ¶
type Cache struct {
// contains filtered or unexported fields
}
func (*Cache) Handle ¶
Handle is a Simple function that will cache the response for given handler in redis and instead of responding with the result from the handler it will simply dump the contents of the redis key if it exists.
func (*Cache) HandleWithParams ¶
HandleWithParams is the same as Handle but caches for the GET params rather than discarding them.
Source Files
¶
- main.go
Click to show internal directories.
Click to hide internal directories.